def add(a,b):
    return a+b
def sub(a,b):
    return a-b
def mult(a,b):
    return a*b
def div(a,b):
    try:
        res = a/b
    except ZeroDivisionError:
        print("Division by 0 is not allowed")
        print("The denominator is approximated as 10^-10")
        res = a/10**(-10)
    finally:
        return res


import random
import magic_calculator.functions as f
def magic(a,b):
    num = random.rarandint(1,4)
    if num == 1:
        return f.add(a,b)
    elif num == 2:
        return f.sub(a,b)
    elif num == 3:
        return f.mult(a,b)
    elif num == 4:
        return f.div(a, b)


import setuptools

# Reads the content of your README.md into a variable to be used in the setup below
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name='magic_calculator',                           # should match the package folder
    packages=['magic_calculator'],                     # should match the package folder
    version='0.4',                                # important for updates
    license='MIT',                                  # should match your chosen license
    description='performs magic calculation',
    long_description=long_description,              # loads your README.md
    long_description_content_type="text/markdown",  # README.md is of type 'markdown'
    author='Soumen Mondal',
    author_email='mondalsoumen00@gmail.com',
    url='https://github.com/soumen448/magic_calculator',
    install_requires=['requests'],                  # list all packages that your package uses
    keywords=["pypi", "magic_calculator", "tutorial"], #descriptive meta-data
    classifiers=[                                   # https://pypi.org/classifiers
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.9',
    ],
    
    download_url="https://github.com/soumen448/magic_calculator/archive/refs/tags/0.4.tar.gz",
)